;Simulation of DCSIGN domains on a DC interacting with a fungal contact site displaying Als family adhesins.
;The goal of this simulation is to investigate the effects of binding avidity and mode of lateral transport
;on contact site structures formed by DCSIGN and the kinetics of DCSIGN recruitment.
;Aaron Neumann  Mar 08 2014
;updated by Rohan Choraghe May 20 2020



globals
  [
    domain_sigma_m
    step_sigma_m
    contact_radius_m
    binding_radius_m
    domain_x
    domain_y
    domain_heading
    next_heading
    next_fd
    domain_counter
    domain_create_counter
    domain_number
    density_setpt
    DCSIGN_deficit
    DCSIGN_domain_needed
    contact_fraction ;the fraction of DCSIGN domains in the contact
    density_enrichment ;the fold amount of DCSIGN domains in the contact relative to what would be expected by random distribution in the
                       ;contact site's area.
    radial_shell_domains; counts the number of DCSIGN domains in the outer 10% radial shell of the contact.
    filename_view filename_world
 coupling_random
  AMF_m
  density_enrichment_2
]

breed [DCSIGNs DCSIGN]
DCSIGNs-own [domain_ID bound which_ALS_bound]

breed [ALSs ALS]
ALSs-own [orig_x orig_y ALS_gyration_radius_m bound which_DCSIGN_bound]

to setup
clear-all
reset-ticks

;assigns key variables that control domain formation and mobility
  set domain_sigma_m domain_sigma / patch_size ;size of DCSIGN domains
  set AMF_m AMF / (patch_size * tick_per_sec) ; how far DCSIGN moves with AFM
  set step_sigma_m step_sigma / patch_size ;how far DCSIGN domain moves per time tick
  set domain_number int (domain_density * (world-width * world-height * patch_size ^ 2)) ;how many DCSIGN domains
  set contact_radius_m contact_radius / patch_size ;size of contact site between DC and yeast
  set binding_radius_m binding_radius / patch_size ;size of zone within which binding can happen

  set filename_view word (word (word (word "Run#" behaviorspace-run-number ) "_" ) date-and-time ) ".png"
  set filename_world word (word (word (word "Run#" behaviorspace-run-number ) "_" ) date-and-time ) ".csv"

;creates domain groups, spreads in gaussian shape of domain, forms links to other members of domain
set domain_create_counter 1
repeat domain_number
  [
    set domain_x random-xcor
    set domain_y random-ycor

    create-DCSIGNs DCSIGNs_per_domain * DCSIGN_multimerization
      [
        set color yellow
        set bound false
        set which_ALS_bound -1
        setxy domain_x domain_y
        set heading random 360
        fd random-normal 0.0 domain_sigma_m
        set domain_ID domain_create_counter
        ask one-of DCSIGNs with [domain_ID = domain_create_counter]
          [
            create-links-with other DCSIGNs with [domain_ID = domain_create_counter]
          ]
      ]
    set domain_create_counter (domain_create_counter + 1)
  ]

;creates ALS proteins in random distribution and initializes them for gyration mobility

create-ALSs int (ALS_density * pi * contact_radius ^ 2)
  [
    set color red
    set bound false
    set which_DCSIGN_bound -1
    set xcor (random-float (2 * contact_radius_m) - contact_radius_m)
    set ycor (random-float (2 * contact_radius_m) - contact_radius_m)
    while [ sqrt(xcor ^ 2 + ycor ^ 2) > contact_radius_m]
      [
        set xcor (random-float (2 * contact_radius_m) - contact_radius_m)
        set ycor (random-float (2 * contact_radius_m) - contact_radius_m)
      ]

    set orig_x xcor
    set orig_y ycor
    set ALS_gyration_radius_m ALS_gyration_radius / patch_size
  ]

;shades the patches in the contact site dark red
ask patches with [sqrt((pxcor * patch_size) ^ 2 + (pycor * patch_size) ^ 2) <= contact_radius] [set pcolor 11]

;defines the density setpoint that will be used to keep the non-contact area at constant DCSIGN density
;units: DCSIGN polypeptides per um^2 simulation space
set density_setpt domain_density * DCSIGNs_per_domain * DCSIGN_multimerization


;reports the total sim area
type "Total simulation area (um^2) = " print (world-width * world-height * patch_size ^ 2) / 1000000


end

to go

;determines binding and immobilization of DCSIGNs and ALSs (probabilistic)

  ask DCSIGNs with [bound = false AND count ALSs with [distance myself <= binding_radius_m and bound = false ] > 0 ]
    [
        if (random-float 1 < assoc_prob)
          [
            set bound true
            set color blue
            set which_ALS_bound [who] of one-of ALSs with [distance myself <= binding_radius_m]
            ask ALS which_ALS_bound
              [
                set bound true
                ;set ALS_gyration_radius_m 0
                set color green
                set which_DCSIGN_bound [who] of one-of DCSIGNs with [ which_ALS_bound = [who] of myself]
              ]
          ]
    ]


;frees agents from binding interactions and immobilization (probabilistic)
  ask DCSIGNs with [bound = true]
    [
      if random-float 1 < dissoc_prob
        [
          set color yellow
          set bound false
          ask Als which_ALS_bound
            [
              set color red
              set bound false
              ;set ALS_gyration_radius_m ALS_gyration_radius / patch_size
              set which_DCSIGN_bound -1
            ]
          set which_ALS_bound -1
        ]
    ]


;causes DCSIGN domains to randomly diffuse in 2D space


   set coupling_random random-float 100



  set domain_counter 1
 repeat domain_create_counter
   ;if coupling_random <= 100

[

      set next_heading random 360
     set next_fd random-normal 0.0 step_sigma_m
      if count DCSIGNs with [((domain_ID = domain_counter) and (bound = true))] = 0 and random-float 1 < .1
        [
          ask DCSIGNs with [domain_ID = domain_counter]
            [ if distancexy 0 0 > contact_radius_m and coupling_random <= 100 [
              ask DCSIGNs with [domain_ID = domain_counter] [set heading next_heading
              fd next_fd ]
            ]
        ]


          ask DCSIGNs with [domain_ID = domain_counter]
             [ if distancexy 0 0 <= contact_radius_m and coupling_random > coupling [
              ask DCSIGNs with [domain_ID = domain_counter] [set heading next_heading
              fd next_fd ]
                ]
              ]


          ask DCSIGNs with [domain_ID = domain_counter]
             [ if distancexy 0 0 <= contact_radius_m and coupling_random < coupling [
              ask DCSIGNs with [domain_ID = domain_counter] [ set heading towards patch 0 0
          fd AMF_m ]
        ]

      ]
    ]
      set domain_counter (domain_counter + 1)
    ]


;measure the enrichment of domains in the contact as
;1) the fraction of domains found inside the contact
;2) enrichment of domain density relative to that expected from the model's domain density parameterization
;3) the number of domains in the outermost 10% of the contact site radius
  set contact_fraction (count DCSIGNs with [distancexy 0 0 <= contact_radius_m] / count DCSIGNs)
  set density_enrichment (count DCSIGNs with [distancexy 0 0 <= contact_radius_m] / (pi * contact_radius ^ 2 * (count DCSIGNs / (world-width * world-height * patch_size ^ 2))))
  set density_enrichment_2 (count DCSIGNs with [distancexy 0 0 <= contact_radius_m] / (pi * contact_radius ^ 2))/ ((count DCSIGNs - count DCSIGNs with [distancexy 0 0 <= contact_radius_m]) / ((world-width * world-height * patch_size ^ 2)-(pi * contact_radius ^ 2)))
  set radial_shell_domains ((count DCSIGNs with [distancexy 0 0 <= contact_radius_m and distancexy 0 0 > (0.9 * contact_radius_m)]) /
                              (pi * contact_radius ^ 2 * (count DCSIGNs / (world-width * world-height * patch_size ^ 2)) - (pi * (0.9 * contact_radius ^ 2) * (count DCSIGNs / (world-width * world-height * patch_size ^ 2)))) )

;create new DCSIGNs to keep the non-contact area at setpoint as they become trapped in the contact site
;DCSIGN_deficit is the integer number of DCSIGN polypeptides that are short of the expected number for the non-contact area at the density_setpt
set DCSIGN_deficit (int  (density_setpt *  ((world-width * world-height * patch_size ^ 2)  - (pi * contact_radius ^ 2)) -
      (count DCSIGNs with [distancexy 0 0 > contact_radius_m]) ))

;DCSIGN_domain_needed tells how many domains need to be created.
;Nothing should be created in the model until the deficit reaches the size of an entire domain
set DCSIGN_domain_needed int (DCSIGN_deficit / (DCSIGNs_per_domain * DCSIGN_multimerization))

repeat DCSIGN_domain_needed
  [

    set domain_heading random 360

    create-DCSIGNs DCSIGNs_per_domain * DCSIGN_multimerization
      [
        set color yellow
        set bound false
        set which_ALS_bound -1
        set heading domain_heading
        fd max-pxcor * 0.9
        set heading random 360
        fd random-normal 0.0 domain_sigma_m
        set domain_ID domain_create_counter
        ask one-of DCSIGNs with [domain_ID = domain_create_counter]
          [
            create-links-with other DCSIGNs with [domain_ID = domain_create_counter]
          ]
      ]
    set domain_create_counter (domain_create_counter + 1)
  ]

tick

end
@#$#@#$#@
GRAPHICS-WINDOW
601
10
1210
620
-1
-1
1.5
1
10
1
1
1
0
1
1
1
-200
200
-200
200
0
0
1
ticks
30.0

BUTTON
283
173
349
206
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
362
172
496
205
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
21
245
193
278
patch_size
patch_size
0
100
25.0
1
1
nm 
HORIZONTAL

SLIDER
27
324
199
357
domain_sigma
domain_sigma
0
500
75.0
1
1
nm
HORIZONTAL

SLIDER
29
366
201
399
step_sigma
step_sigma
0
500
161.0
1
1
nm
HORIZONTAL

SLIDER
215
245
539
278
domain_density
domain_density
0
.001
1.2E-6
.0001
1
domains/nm^2
HORIZONTAL

SLIDER
27
406
199
439
contact_radius
contact_radius
0
2000
1000.0
1
1
nm
HORIZONTAL

SLIDER
28
444
198
477
DCSIGNs_per_domain
DCSIGNs_per_domain
0
25
4.0
1
1
NIL
HORIZONTAL

SLIDER
23
283
196
316
ALS_gyration_radius
ALS_gyration_radius
0
500
50.0
1
1
nm
HORIZONTAL

SLIDER
214
289
536
322
ALS_density
ALS_density
0
.001
1.7E-4
.0001
1
ALS/nm^2
HORIZONTAL

SLIDER
212
331
540
364
dissoc_prob
dissoc_prob
0
1
0.02
.01
1
NIL
HORIZONTAL

SLIDER
214
374
541
407
assoc_prob
assoc_prob
0
1
0.5
.01
1
NIL
HORIZONTAL

SLIDER
29
485
201
518
DCSIGN_multimerization
DCSIGN_multimerization
0
10
2.0
1
1
NIL
HORIZONTAL

SLIDER
31
525
203
558
tick_per_sec
tick_per_sec
0
100
10.0
1
1
NIL
HORIZONTAL

MONITOR
509
166
584
211
time (min)
(ticks / tick_per_sec) / 60
2
1
11

PLOT
6
10
206
160
contact fraction
ticks
contact fraction
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"contact fraction" 1.0 0 -2674135 true "" "plot contact_fraction"

PLOT
208
10
408
160
density enrichment
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"density enrichment" 1.0 0 -13345367 true "" "plot density_enrichment"

PLOT
409
10
600
160
outer 10% domains
ticks
domains (outer 10% contact)
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"radial_shell_domains" 1.0 0 -10899396 true "" "plot radial_shell_domains"

SLIDER
32
564
204
597
binding_radius
binding_radius
0
20
5.0
1
1
nm
HORIZONTAL

SLIDER
213
419
385
452
AMF
AMF
0
200
10.0
10
1
nm
HORIZONTAL

SLIDER
397
419
569
452
coupling
coupling
0
100
0.0
1
1
NIL
HORIZONTAL

PLOT
281
469
481
619
density enrichmment 2
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"density_enrichment_2" 1.0 0 -16777216 true "" "plot density_enrichment_2"

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="02112014_223pm_contactsite_1h_ADrates_inittest" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="3600"/>
    <metric>contact_fraction</metric>
    <metric>density_enrichment</metric>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conactsite_021214_ADrates_3x_view&amp;world_1h_domains" repetitions="3" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-view filename_view
export-world filename_world</final>
    <timeLimit steps="36000"/>
    <metric>contact_fraction</metric>
    <metric>density_enrichment</metric>
    <metric>radial_shell_domains</metric>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="0.99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.001"/>
      <value value="0.01"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conactsite_021314_ADrates_3x_view&amp;world_1h_eqdensMonomer" repetitions="3" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-view filename_view
export-world filename_world</final>
    <timeLimit steps="36000"/>
    <metric>contact_fraction</metric>
    <metric>density_enrichment</metric>
    <metric>radial_shell_domains</metric>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="0.99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.001"/>
      <value value="0.01"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conactsite_021914_ADrates_3x_view&amp;world_1h_eqdensDimer" repetitions="3" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-view filename_view
export-world filename_world</final>
    <timeLimit steps="36000"/>
    <metric>contact_fraction</metric>
    <metric>density_enrichment</metric>
    <metric>radial_shell_domains</metric>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="0.99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.001"/>
      <value value="0.01"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conactsite_031114_ADrates_3x_view&amp;world_1h_tetramer_upperbound2" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-view filename_view
export-world filename_world</final>
    <timeLimit steps="36000"/>
    <metric>contact_fraction</metric>
    <metric>density_enrichment</metric>
    <metric>radial_shell_domains</metric>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conactsite_031114_ADrates_3x_view&amp;world_1h_tetramer_upperbound3" repetitions="3" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-view filename_view
export-world filename_world</final>
    <timeLimit steps="36000"/>
    <metric>contact_fraction</metric>
    <metric>density_enrichment</metric>
    <metric>radial_shell_domains</metric>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0"/>
      <value value="1.0E-4"/>
      <value value="0.001"/>
      <value value="0.01"/>
      <value value="0.1"/>
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conactsite_031114_ADrates_3x_view&amp;world_1h_tetramer_upperboundtest" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-view filename_view
export-world filename_world</final>
    <timeLimit steps="1000"/>
    <metric>density_enrichment</metric>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0"/>
      <value value="0"/>
      <value value="0"/>
      <value value="1"/>
      <value value="1"/>
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conactsite_031414_ADrates_3x_view&amp;world_1h_tetramer_full" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-view filename_view
export-world filename_world</final>
    <timeLimit steps="36000"/>
    <metric>density_enrichment</metric>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="0.9"/>
      <value value="0.925"/>
      <value value="0.095"/>
      <value value="0.975"/>
      <value value="0.99"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0"/>
      <value value="1.0E-4"/>
      <value value="0.001"/>
      <value value="0.01"/>
      <value value="0.1"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conactsite_031814_ADrates_3x_view&amp;world_1h_tetramer_full_3" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-view filename_view
export-world filename_world</final>
    <timeLimit steps="36000"/>
    <metric>density_enrichment</metric>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="0.9"/>
      <value value="0.925"/>
      <value value="0.095"/>
      <value value="0.975"/>
      <value value="0.99"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0"/>
      <value value="1.0E-4"/>
      <value value="0.001"/>
      <value value="0.01"/>
      <value value="0.1"/>
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Conatct_site_200305" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>export-view filename_view
export-world filename_world</final>
    <metric>density_enrichment</metric>
  </experiment>
  <experiment name="experiment" repetitions="5" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>density_enrichment</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Contact_site_200305_1" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>density_enrichment</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_200306" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="6000"/>
    <metric>density_enrichment</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.7E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Contact_site_200527" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="6000"/>
    <metric>density_enrichment_2</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.7E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.01"/>
      <value value="0.03"/>
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="0"/>
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Contact_site_200528" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="6000"/>
    <metric>density_enrichment_2</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.7E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.01"/>
      <value value="0.03"/>
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="0"/>
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Contact_site_200528" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="6000"/>
    <metric>density_enrichment_2</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.7E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.01"/>
      <value value="0.03"/>
      <value value="0.05"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="0"/>
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Contact_site_200614" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="6000"/>
    <metric>density_enrichment_2</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.7E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.01"/>
      <value value="0.03"/>
      <value value="0.05"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="0"/>
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Contact_site_200626" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="6000"/>
    <metric>density_enrichment_2</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.7E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="0"/>
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Contact_site_200629" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="6000"/>
    <metric>density_enrichment_2</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.7E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="0"/>
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Contact_site_200629" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="6000"/>
    <metric>density_enrichment_2</metric>
    <enumeratedValueSet variable="tick_per_sec">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_density">
      <value value="1.2E-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="domain_sigma">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_density">
      <value value="1.7E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AMF">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="binding_radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissoc_prob">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coupling">
      <value value="0"/>
      <value value="20"/>
      <value value="40"/>
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ALS_gyration_radius">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGN_multimerization">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contact_radius">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patch_size">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assoc_prob">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step_sigma">
      <value value="161"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DCSIGNs_per_domain">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
